==> xoonips-3.30.tar.gz: xoonips-3.30/xoonips/class/base/transaction.class.php <==
<?php
// $Revision: 1.1.2.3 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

/**
 * @brief XooNIps transaction class.
 *
 * Don't call constructor. Use {@link XooNIpsTransaction::getInstance()} to get instance.
 */
class XooNIpsTransaction
{
    var $db;

    /**
     * @brief create XooNIpsTransaction.
     *
     * @param XoopsDatabase $db
     */
    function XooNIpsTransaction(&$db) 
    {
        $this->db = &$db;
    }

    /**
     * start transaction
     *
     */
    function start() 
    {
        $this->db->query("START TRANSACTION");
    }

    /**
     * commit
     *
     */
    function commit() 
    {
        $this->db->query("COMMIT");
    }

    /**
     * rollback
     *
     */
    function rollback() 
    {
        $this->db->query("ROLLBACK");
    }

    /**
     * return instance of XooNIpsTransaction
     *
     */
    function &getInstance() 
    {
        static $singleton = null;
        if (!isset($singleton)) $singleton = new XooNIpsTransaction($GLOBALS['xoopsDB']);
        return $singleton;
    }
}
?>

==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/class/base/transaction.class.php <==
<?php
// $Revision: 1.1.2.4 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

/**
 * @brief XooNIps transaction class.
 *
 * Don't call constructor. Use {@link XooNIpsTransaction::getInstance()} to get instance.
 */
class XooNIpsTransaction
{
    var $db;

    /**
     * @brief create XooNIpsTransaction.
     *
     * @param XoopsDatabase $db
     */
    function XooNIpsTransaction(&$db) 
    {
        $this->db = &$db;
    }

    /**
     * start transaction
     *
     */
    function start() 
    {
        $this->db->queryF("START TRANSACTION");
    }

    /**
     * commit
     *
     */
    function commit() 
    {
        $this->db->queryF("COMMIT");
    }

    /**
     * rollback
     *
     */
    function rollback() 
    {
        $this->db->queryF("ROLLBACK");
    }

    /**
     * return instance of XooNIpsTransaction
     *
     */
    function &getInstance() 
    {
        static $singleton = null;
        if (!isset($singleton)) $singleton = new XooNIpsTransaction($GLOBALS['xoopsDB']);
        return $singleton;
    }
}
?>
